@@ -1,13 +1,10 @@
 package PNI::Scenario;
 use strict;
-use warnings;
-our $VERSION = '0.15';
-### use Smart::Comments;
 use base 'PNI::Node';
-use PNI::Edge 0.15;
-use PNI::Error 0.15;
-use PNI::File 0.15;
-use PNI::Node 0.15;
+use PNI::Edge;
+use PNI::Error;
+use PNI::File;
+use PNI::Node;
 
 sub new {
     my $class = shift;
@@ -19,8 +16,8 @@ sub new {
 
     # $file is not required but should be a PNI::File
     my $file = $arg->{file};
-    if ( defined $file ) {
-        $file->isa('PNI::File') or return PNI::Error::invalid_argument_type;
+    if ( defined $file and not $file->isa('PNI::File') ) {
+        return PNI::Error::invalid_argument_type;
     }
     $self->add( file => $file );
 
@@ -31,7 +28,7 @@ sub new {
     return $self;
 }
 
-# return $edge
+# return $edge: PNI::Edge
 sub add_edge {
     my $self = shift;
     my $edge = PNI::Edge->new(@_) or return PNI::Error::unable_to_create_item;
@@ -39,7 +36,7 @@ sub add_edge {
     return $self->get('edges')->{ $edge->id } = $edge;
 }
 
-# return $node
+# return $node: PNI::Node
 sub add_node {
     my $self = shift;
     my $arg  = {@_};
@@ -75,97 +72,8 @@ sub add_scenario {
     return $self->get('scenarios')->{ $scenario->id } = $scenario;
 }
 
-# my $previous_content = $self->clear_all;
-# return \%content
-sub clear_all {
-    my $self    = shift;
-    my $content = {};
-
-    my $edges = $self->get_edges;
-    my $nodes = $self->get_nodes;
-
-    $content = { edges => $edges, nodes => $nodes, };
-
-    # clear stuff
-    $self->set( edges => {} );
-    $self->set( file  => undef );
-    $self->set( nodes => {} );
-
-    return $content;
-}
-
-sub get_edges { return shift->get('edges') }
-
-sub get_file { return shift->get('file') }
-
-# return %nodes
-sub get_nodes { return values %{ shift->get('nodes') }; }
-
-# return 1
-sub load_file {
-
-    #TODO put this code inside PNI::File
-    my $self = shift;
-
-    my $file = $self->get_file;
-
-    my %new_id_of;
-    my %get_node_by_id;
-    my $previous_content = $self->clear_all;
-
-    my $stored_edges = $file->get_edges;
-    my $stored_nodes = $file->get_nodes;
-
-    # create nodes
-    for my $stored_node_id ( keys %{$stored_nodes} ) {
-
-        my $stored_node = $stored_nodes->{$stored_node_id};
-
-        my $type   = $stored_node->{type};
-        my $inputs = $stored_node->{inputs};
-        my $node   = $self->add_node(
-            type   => $type,
-            inputs => $inputs,
-        );
-
-        my $node_id = $node->id;
-        $new_id_of{$stored_node_id} = $node_id;
-
-        # remember node <--> node_id relation
-        $get_node_by_id{$node_id} = $node;
-    }
-
-    # create edges
-    for my $stored_edge_id ( keys %{$stored_edges} ) {
-
-        my $stored_edge = $stored_edges->{$stored_edge_id};
-
-        # stored_egde => { source_id => x, target_id => y,
-        #                  source_name => 'foo', target_name => 'bar' }
-        my $stored_source_id = $stored_edge->{source_id};
-        my $stored_target_id = $stored_edge->{target_id};
-        my $source_name      = $stored_edge->{source_name};
-        my $target_name      = $stored_edge->{target_name};
-
-        my $source_id   = $new_id_of{$stored_source_id};
-        my $source_node = $get_node_by_id{$source_id};
-        my $source      = $source_node->get_input($source_name);
-
-        my $target_id   = $new_id_of{$stored_target_id};
-        my $target_node = $get_node_by_id{$target_id};
-        my $target      = $target_node->get_input($target_name);
-
-        my $edge = $self->add_edge( source => $source, target => $target );
-    }
-
-    return 1;
-}
-
-sub set_file {
-    my $self = shift;
-    my $file = shift or return PNI::Error::missing_required_argument;
-    return $self->set( file => $file );
-}
+# return @nodes: PNI::Node
+sub get_nodes { values %{ shift->get('nodes') } }
 
 # return 1
 sub task {
@@ -176,10 +84,8 @@ sub task {
     # Start with nodes without a parent
     my %parents_of;
     for my $node ( $self->get_nodes ) {
-        $parents_of{$node} = [];
-        for my $edge ( $node->get_input_edges ) {
-            push @{ $parents_of{$node} }, $edge->get_source_node;
-        }
+        $parents_of{$node} =
+          [ map { $_->get_source_node } $node->get_input_edges ];
     }
 
     my %has_run_task_of;
@@ -187,7 +93,7 @@ sub task {
   RUN_TASKS:
     for my $node ( $self->get_nodes ) {
 
-        # discard nodes that run task yet
+        # discard nodes that run their task yet
         next if $has_run_task_of{$node};
 
         # wait until all parent nodes run
@@ -219,53 +125,62 @@ sub task {
     # check if all tasks run
     for my $node ( $self->get_nodes ) {
         if   ( $has_run_task_of{$node} ) { }
+        ### TODO apply Marcos patches !!!!
         else                             { goto RUN_TASKS; }
     }
 
+    # at this point all tasks are run so reset all slots "changed" flag
+    for my $node ( $self->get_nodes ) {
+        for my $slot ( $node->get_inputs, $node->get_outputs ) {
+            $slot->set( changed => 0 );
+        }
+    }
+
     return 1;
 }
 
 1;
 __END__
 
+################################
+# TODO consider rename this package as PNI::Tree
+
 =head1 NAME
 
 PNI::Scenario - is a persistent PNI graph
 
-
 =head1 METHODS
 
 =head2 C<add_edge>
 
 =head2 C<add_node>
 
+Adds a new node, given a PNI node type. 
+L<PNI::Scenario> checks if PNI node type is valid, then initializes it.
+
+    # if arg type is not provided, creates a dummy node:
+    my $dummy_node = $scenario->add_node;
+    # it can be useful for tests, and you can also decorate it later.
+
+    # suppose 'Foo::Bar' is a valid PNI node type,
+    # this creates a PNI::Node::Foo::Bar.
+    my $node_foo = $scenario->add_node( type => 'Foo::Bar' );
+
+    # an additional inputs => {} arg, is used to set node inputs data
+    # before running the first node task.
+    $node = $scenario->add_node( 
+        type => 'Perlfunc::Print',
+        inputs => {
+            list => [ 'Hello World!' ],
+            do_print => 1,
+        }
+    );
+
 =head2 C<add_scenario>
 
-=head2 C<clear_all>
-
-=head2 C<get_file>
-
 =head2 C<get_nodes>
 
-=head2 C<get_edges>
-
-=head2 C<load_file>
-
-=head2 C<set_file>
-
 =head2 C<task>
 
-
-
-=head1 AUTHOR
-
-G. Casati , E<lt>fibo@cpan.orgE<gt>
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright (C) 2009-2011, Gianluca Casati
-
-This program is free software, you can redistribute it and/or modify it
-under the same terms of the Artistic License version 2.0 .
-
 =cut
+
