@@ -1,11 +1,8 @@
 package PNI::Slot::In;
 use strict;
-use warnings;
-our $VERSION = '0.15';
-### use Smart::Comments;
 use base 'PNI::Slot';
-use PNI::Edge 0.15;
-use PNI::Error 0.15;
+use PNI::Edge;
+use PNI::Error;
 
 sub new {
     my $class = shift;
@@ -25,24 +22,20 @@ sub add_edge {
     return $self->set( edge => $edge );
 }
 
-sub get_edge { return shift->get('edge'); }
+# return $edge: PNI::Edge
+sub get_edge { shift->get('edge') }
 
 # return 0 or 1
-sub is_connected {
-    my $self = shift;
-    my $edge = $self->get_edge;
-    if   ( defined $edge ) { return 1 }
-    else                   { return 0; }
-}
+sub is_connected { defined( shift->get_edge ) ? 1 : 0 }
 
-# return $edge
+# return $edge: PNI::Edge
 sub join_to {
     my $self = shift;
 
     # output_slot arg is required
     my $output_slot = shift or return PNI::Error::missing_required_argument;
 
-    return PNI::Edge->new( target => $self, source => $output_slot );
+    return PNI::Edge->new( source => $output_slot, target => $self );
 }
 
 1;
@@ -52,7 +45,6 @@ __END__
 
 PNI::Slot::In - input slot
 
-
 =head1 METHODS
 
 =head2 C<add_edge>
@@ -61,19 +53,10 @@ PNI::Slot::In - input slot
 
 =head2 C<is_connected>
 
+    $in->is_connected;
+
 =head2 C<join_to>
 
-
-
-=head1 AUTHOR
-
-G. Casati , E<lt>fibo@cpan.orgE<gt>
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright (C) 2009-2011, Gianluca Casati
-
-This program is free software, you can redistribute it and/or modify it
-under the same terms of the Artistic License version 2.0 .
+    my $new_edge = $in->join_to( $out );
 
 =cut
