@@ -1,10 +1,7 @@
 package PNI::Slot::Out;
 use strict;
-use warnings;
-our $VERSION = '0.15';
-### use Smart::Comments;
 use base 'PNI::Slot';
-use PNI::Error 0.15;
+use PNI::Error;
 
 sub new {
     my $class = shift;
@@ -29,12 +26,7 @@ sub add_edge {
 sub get_edges { return values %{ shift->get('edges') }; }
 
 # return 0 or 1
-sub is_connected {
-    my $self  = shift;
-    my @edges = $self->get_edges;
-    if   (@edges) { return 1 }
-    else          { return 0; }
-}
+sub is_connected { return shift->get_edges ? 1 : 0; }
 
 # return $edge
 sub join_to {
@@ -43,7 +35,7 @@ sub join_to {
     # input_slot arg is required
     my $input_slot = shift or return PNI::Error::missing_required_argument;
 
-    return PNI::Edge->new( target => $input_slot, source => $self );
+    return PNI::Edge->new( source => $self, target => $input_slot );
 }
 
 1;
@@ -53,7 +45,6 @@ __END__
 
 PNI::Slot::Out - output slot
 
-
 =head1 ATTRIBUTES
 
 =head2 C<edges>
@@ -68,17 +59,5 @@ PNI::Slot::Out - output slot
 
 =head2 C<join_to>
 
-
-
-=head1 AUTHOR
-
-G. Casati , E<lt>fibo@cpan.orgE<gt>
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright (C) 2009-2011, Gianluca Casati
-
-This program is free software, you can redistribute it and/or modify it
-under the same terms of the Artistic License version 2.0 .
-
 =cut
+
